@@ -1,5 +1,23 @@
 import os
 from urllib.request import urlretrieve
+from tqdm import tqdm
+
+# This is used to show progress when downloading.
+# see here: https://github.com/tqdm/tqdm#hooks-and-callbacks
+class TqdmUpTo(tqdm):
+    """Provides `update_to(n)` which uses `tqdm.update(delta_n)`."""
+    def update_to(self, b=1, bsize=1, tsize=None):
+        """
+        b  : int, optional
+            Number of blocks transferred so far [default: 1].
+        bsize  : int, optional
+            Size of each block (in tqdm units) [default: 1].
+        tsize  : int, optional
+            Total size (in tqdm units). If [default: None] remains unchanged.
+        """
+        if tsize is not None:
+            self.total = tsize
+        self.update(b * bsize - self.n)  # will also set self.n = b * bsize
 
 def download(model=None):
     # downloading from dropbox
@@ -34,23 +52,29 @@ def download(model=None):
     # make directories as needed
     try:
         os.mkdir(pwd + "/data")
-        dirs = [
-            "/data/tfidf",
-            "/data/tfidf_bi",
-            "/data/doc2vec",
-            "/data/gpt2",
-        ]
-        for dir in dirs:
-            if (model is None or model in dir):
-                os.mkdir(pwd + dir)
     except FileExistsError:
-        print("Directory already exists... perhaps you already downloaded the data? Overwriting...")
+        print(pwd + "/data" + " directory already exists, some other models downloaded. Continuing...")
+    
+    dirs = [
+        "/data/tfidf",
+        "/data/tfidf_bi",
+        "/data/doc2vec",
+        "/data/gpt2",
+    ]
+    for dir in dirs:
+        if (model is None or model in dir):
+            try:
+                os.mkdir(pwd + dir)
+            except FileExistsError:
+                print(pwd + dir + " directory already exists... perhaps you already downloaded the data? Overwriting...")
 
     # download the files
     for sink, source in urls.items():
         if (model is None or model in sink):
             print("Downloading " + sink + " from " + source)
             try:
-                urlretrieve(source, filename=pwd+sink)
+                with TqdmUpTo(unit='B', unit_scale=True, miniters=1, desc=url.split('/')[-1]) as t:  # all optional kwargs
+                    urlretrieve(source, filename=pwd+sink, reporthook=t.update_to, data=None)
+                    t.total = t.n
             except urllib.error.ContentTooShortError:
                 print("Download incomplete?")
\ No newline at end of file
